@@ -67,6 +67,8 @@ University of California.
 #include <X11/Xproto.h>
 #include <X11/Xlibint.h>
 #include <X11/extensions/xtestext1.h>
+#include <X11/extensions/xtestext1proto.h>
+#include <X11/extensions/XTest.h>
 
 /******************************************************************************
  * variables
@@ -76,14 +78,14 @@ University of California.
  * Holds the request type code for this extension.  The request type code
  * for this extension may vary depending on how many extensions are installed
  * already, so the initial value given below will be added to the base request
- * code that is aquired when this extension is installed.
+ * code that is acquired when this extension is installed.
  */
 static int		XTestReqCode = 0;
 /*
  * Holds the two event type codes for this extension.  The event type codes
  * for this extension may vary depending on how many extensions are installed
  * already, so the initial values given below will be added to the base event
- * code that is aquired when this extension is installed.
+ * code that is acquired when this extension is installed.
  *
  * These two variables must be available to programs that use this extension.
  */
@@ -1200,7 +1202,7 @@ int	ack_flag)
 	/*
 	 * points to XTestIdentifyMyEvent
 	 */
-	Bool	(*func_ptr)();
+	Bool	(*func_ptr)(Display *, XEvent *, XPointer);
 
 	/*
 	 * write the input actions to the server
@@ -1262,7 +1264,7 @@ static	Bool
 XTestIdentifyMyEvent(
 Display	*display,
 /*
- * Holds the event that this routiine is supposed to look at.
+ * Holds the event that this routine is supposed to look at.
  */
 XEvent	*event_ptr,
 /*
